django-qa was started by Arjun Komath (<arjunkomath@gmail.com>) in 2015 as a
way to have a simple and pluggable Q&A App for Django projects.

Contributors
============
Arjun Komath
Cristian Vargas
Sebastian Reyes
Jose Ariza
The SWAPPS development team
